#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 yesod-test
version:              1.6.23
visibility:           public
id:                   yesod-test-1.6.23-FZTXV9qShmY1CbxfF0dAQG
key:                  yesod-test-1.6.23-FZTXV9qShmY1CbxfF0dAQG
license:              MIT
maintainer:           Michael Snoyman, Greg Weber, Nubis <nubis@woobiz.com.ar>
author:               Nubis <nubis@woobiz.com.ar>
stability:            Experimental
homepage:             http://www.yesodweb.com
synopsis:             integration testing for WAI/Yesod Applications
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-test>

category:             Web, Yesod, Testing
abi:                  0fc19ac5be3ce31bbc721d949c48f8aa
exposed:              True
exposed-modules:
    Yesod.Test Yesod.Test.CssQuery Yesod.Test.Internal
    Yesod.Test.Internal.SIO Yesod.Test.TransversingCSS

import-dirs:          /usr/lib/ghc-9.6.6/site-local/yesod-test-1.6.23
library-dirs:         /usr/lib/ghc-9.6.6/site-local/yesod-test-1.6.23
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/yesod-test-1.6.23
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-yesod-test
hs-libraries:         HSyesod-test-1.6.23-FZTXV9qShmY1CbxfF0dAQG
depends:
    HUnit-1.6.2.0-DydRkK1Ty562EFYgxreweA
    aeson-2.2.2.0-Dt9IcEbIPgo3pXUjrBlJbR
    attoparsec-0.14.4-9ctfIIumed0I3W5C5GaWiL base-4.18.2.1
    blaze-builder-0.4.4.1-M4s5cE8K8cEVLaASoTkxk
    blaze-html-0.9.2.0-PSPLizehIBK0KyrDun70k
    blaze-markup-0.8.3.0-En1LhSl79346pvouIeUq7J bytestring-0.11.5.3
    case-insensitive-1.2.1.0-Gzh99I2Ds5LB1yZuFXcZ2A
    conduit-1.3.6.1-F67YktQmHRqJ5R9QX7ucHV containers-0.6.7
    cookie-0.5.0-Dqi2dsQ09KG8Z0mbWITxu5 directory-1.3.8.5
    hspec-core-2.11.6-5MLr9Dr5NGtGGGWYDFQKhK
    html-conduit-1.3.2.2-LASIb6REfkzCo2SLOqjGoX
    http-types-0.12.4-LSgWFg4mVle7jKIO2vdgXi
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5 mtl-2.3.1
    network-3.1.4.0-435zy6qxTBGFK5XFFiJsye
    pretty-show-1.10-EXsS4VwIV5tJ56gbmVdfrR process-1.6.19.0 text-2.0.2
    time-1.12.2 transformers-0.6.1.0 wai-3.2.4-7vzMwDkBBVH69wuxH7kNR
    wai-extra-3.1.18-FkJl3fQujq328X4evuCipJ
    xml-conduit-1.9.1.4-sKsOKYuT7TJuyp6gbDhmU
    xml-types-0.3.8-ISf6rjkeTjSFXsXdIGBwau
    yesod-core-1.6.28.0-AMLfS4ptXbq7Y8NcdaatBG

haddock-interfaces:   /usr/share/doc/haskell-yesod-test/html/yesod-test.haddock
haddock-html:         /usr/share/doc/haskell-yesod-test/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

